Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS App Mesh Preview.

Actions, resources, and condition keys for AWS App Mesh Preview - Service Authorization Reference

# Actions, resources, and condition keys for AWS App Mesh Preview

AWS App Mesh Preview (service prefix: `appmesh-preview` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by AWS App Mesh Preview
- Resource types defined by AWS App Mesh Preview
- Condition keys for AWS App Mesh Preview

## Actions defined by AWS App Mesh Preview

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
CreateGatewayRoute | Grants permission to create a gateway route that is associated with a virtual gateway | Write | gatewayRoute* |  |
virtualService |  |
CreateMesh | Grants permission to create a service mesh | Write | mesh* |  |
CreateRoute | Grants permission to create a route that is associated with a virtual router | Write | route* |  |
virtualNode |  |
CreateVirtualGateway | Grants permission to create a virtual gateway within a service mesh | Write | virtualGateway* |  |
CreateVirtualNode | Grants permission to create a virtual node within a service mesh | Write | virtualNode* |  |
virtualService |  |
CreateVirtualRouter | Grants permission to create a virtual router within a service mesh | Write | virtualRouter* |  |
CreateVirtualService | Grants permission to create a virtual service within a service mesh | Write | virtualService* |  |
virtualNode |  |
virtualRouter |  |
DeleteGatewayRoute | Grants permission to delete an existing gateway route | Write | gatewayRoute* |  |
DeleteMesh | Grants permission to delete an existing service mesh | Write | mesh* |  |
DeleteRoute | Grants permission to delete an existing route | Write | route* |  |
DeleteVirtualGateway | Grants permission to delete an existing virtual gateway | Write | virtualGateway* |  |
DeleteVirtualNode | Grants permission to delete an existing virtual node | Write | virtualNode* |  |
DeleteVirtualRouter | Grants permission to delete an existing virtual router | Write | virtualRouter* |  |
DeleteVirtualService | Grants permission to delete an existing virtual service | Write | virtualService* |  |
DescribeGatewayRoute | Grants permission to describe an existing gateway route | Read | gatewayRoute* |  |
DescribeMesh | Grants permission to describe an existing service mesh | Read | mesh* |  |
DescribeRoute | Grants permission to describe an existing route | Read | route* |  |
DescribeVirtualGateway | Grants permission to describe an existing virtual gateway | Read | virtualGateway* |  |
DescribeVirtualNode | Grants permission to describe an existing virtual node | Read | virtualNode* |  |
DescribeVirtualRouter | Grants permission to describe an existing virtual router | Read | virtualRouter* |  |
DescribeVirtualService | Grants permission to describe an existing virtual service | Read | virtualService* |  |
ListGatewayRoutes | Grants permission to list existing gateway routes in a service mesh | List | virtualGateway* |  |
ListMeshes | Grants permission to list existing service meshes | List |  |  |
ListRoutes | Grants permission to list existing routes in a service mesh | List | virtualRouter* |  |
ListVirtualGateways | Grants permission to list existing virtual gateways in a service mesh | List | mesh* |  |
ListVirtualNodes | Grants permission to list existing virtual nodes | List | mesh* |  |
ListVirtualRouters | Grants permission to list existing virtual routers in a service mesh | List | mesh* |  |
ListVirtualServices | Grants permission to list existing virtual services in a service mesh | List | mesh* |  |
StreamAggregatedResources | Grants permission to receive streamed resources for an App Mesh endpoint (VirtualNode/VirtualGateway) | Read | virtualGateway |  |
virtualNode |  |
UpdateGatewayRoute | Grants permission to update an existing gateway route for a specified service mesh and virtual gateway | Write | gatewayRoute* |  |
virtualService |  |
UpdateMesh | Grants permission to update an existing service mesh | Write | mesh* |  |
UpdateRoute | Grants permission to update an existing route for a specified service mesh and virtual router | Write | route* |  |
virtualNode |  |
UpdateVirtualGateway | Grants permission to update an existing virtual gateway in a specified service mesh | Write | virtualGateway* |  |
UpdateVirtualNode | Grants permission to update an existing virtual node in a specified service mesh | Write | virtualNode* |  |
UpdateVirtualRouter | Grants permission to update an existing virtual router in a specified service mesh | Write | virtualRouter* |  |
UpdateVirtualService | Grants permission to update an existing virtual service in a specified service mesh | Write | virtualService* |  |
virtualNode |  |
virtualRouter |  |

## Resource types defined by AWS App Mesh Preview

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
mesh | `arn:$ { Partition}:appmesh-preview:$ { Region}:$ { Account}:mesh/$ { MeshName}` |
virtualService | `arn:$ { Partition}:appmesh-preview:$ { Region}:$ { Account}:mesh/$ { MeshName}/virtualService/$ { VirtualServiceName}` |
virtualNode | `arn:$ { Partition}:appmesh-preview:$ { Region}:$ { Account}:mesh/$ { MeshName}/virtualNode/$ { VirtualNodeName}` |
virtualRouter | `arn:$ { Partition}:appmesh-preview:$ { Region}:$ { Account}:mesh/$ { MeshName}/virtualRouter/$ { VirtualRouterName}` |
route | `arn:$ { Partition}:appmesh-preview:$ { Region}:$ { Account}:mesh/$ { MeshName}/virtualRouter/$ { VirtualRouterName}/route/$ { RouteName}` |
virtualGateway | `arn:$ { Partition}:appmesh-preview:$ { Region}:$ { Account}:mesh/$ { MeshName}/virtualGateway/$ { VirtualGatewayName}` |
gatewayRoute | `arn:$ { Partition}:appmesh-preview:$ { Region}:$ { Account}:mesh/$ { MeshName}/virtualGateway/$ { VirtualGatewayName}/gatewayRoute/$ { GatewayRouteName}` |

## Condition keys for AWS App Mesh Preview

App Mesh Preview has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available keys for conditions .

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.